# ImageMetadataResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | Name of the image with optional tag. |
**tag** | **str** | Tag of the image. | [optional]
**digest** | **str** | Digest of the image. |
**repo_tags** | **list[str]** |  |
**created** | **str** | Image creation date and time. |
**docker_version** | **str** | Version of Docker. |
**labels** | **object** | Image labels. |
**architecture** | **str** | Target architecture of image. |
**os** | **str** | Operating system identifier. |
**layers** | **list[str]** |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

